package com.fs.app.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.app.domain.FsAppRole;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * APP角色Mapper接口
 * 
 * @author fs
 * @date 2026-02-26
 */
public interface FsAppRoleMapper extends BaseMapper<FsAppRole>{
    /**
     * 查询APP角色
     * 
     * @param id APP角色主键
     * @return APP角色
     */
    FsAppRole selectFsAppRoleById(Long id);

    /**
     * 查询APP角色以及奖品
     *
     * @param id APP角色主键
     * @return APP角色
     */
    FsAppRole selectFsAppRoleAndRewardsById(Long id);

    /**
     * 查询APP角色列表
     * 
     * @param fsAppRole APP角色
     * @return APP角色集合
     */
    List<FsAppRole> selectFsAppRoleList(FsAppRole fsAppRole);

    /**
     * 新增APP角色
     * 
     * @param fsAppRole APP角色
     * @return 结果
     */
    int insertFsAppRole(FsAppRole fsAppRole);

    /**
     * 修改APP角色
     * 
     * @param fsAppRole APP角色
     * @return 结果
     */
    int updateFsAppRole(FsAppRole fsAppRole);

    /**
     * 删除APP角色
     * 
     * @param id APP角色主键
     * @return 结果
     */
    int deleteFsAppRoleById(Long id);

    /**
     * 批量删除APP角色
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsAppRoleByIds(Long[] ids);

    /**
     * 根据用户ID查询其拥有的最高级别的APP角色信息
     *
     * @param userId 用户ID
     * @param levelSortAsc 指定排序方式，'true'表示数字越小级别越高，'false'表示数字越大级别越高
     * @return FsAppRole 最高级别的角色信息
     */
    FsAppRole selectHighestLevelAppRoleByUserId(@Param("userId") Long userId, @Param("levelSortAsc") String levelSortAsc);

    //根据角色类型获取角色信息列表
    @Select("SELECT * FROM fs_app_role WHERE role_type = #{roleType}")
    List<FsAppRole> selectFsAppRoleListByRoleType(@Param("roleType") Integer roleType);
}
